@@ -10,12 +10,12 @@ from django.db import IntegrityError, models, transaction
 from django.db.models import functions
 
 try:  # pragma: no cover
-    import django.contrib.gis.db.models.functions
+    import django.contrib.gis.db.models.functions  # noqa: F401
     import django.contrib.gis.db.models as gis
-except Exception:  # pragma: no cover
+except Exception:
     gis = None
 
-__version__ = '1.3'
+__version__ = '1.5'
 
 
 def update_wrapper(wrapper, name):
@@ -148,7 +148,7 @@ class F(models.F, Lookup, metaclass=MetaF):
 
     Some ``Func`` objects can also be transformed into lookups,
     if [registered](https://docs.djangoproject.com/en/stable/ref/models/database-functions/#length):
-    ``F.text.length()`` == ``Length(F(text))``,
+    ``F.text.length()`` == ``Length(F('text'))``,
     ``F.text.length > 0`` == ``Q(text__length__gt=0)``.
     """
 
@@ -170,6 +170,8 @@ class F(models.F, Lookup, metaclass=MetaF):
         sin=functions.Sin,
         sqrt=functions.Sqrt,
         tan=functions.Tan,
+        sign=functions.Sign,
+        md5=functions.MD5,
     )
     coalesce = method(functions.Coalesce)
     concat = method(functions.Concat)  # __add__ is taken
@@ -209,17 +211,14 @@ class F(models.F, Lookup, metaclass=MetaF):
     pi = functions.Pi()
     __pow__ = method(functions.Power)
     __round__ = method(functions.Round)
-    if django.VERSION >= (3,):  # pragma: no branch
-        lookups.update(sign=functions.Sign, md5=functions.MD5)
-        sha1 = method(functions.SHA1)
-        sha224 = method(functions.SHA224)
-        sha256 = method(functions.SHA256)
-        sha384 = method(functions.SHA384)
-        sha512 = method(functions.SHA512)
-    if django.VERSION >= (3, 2):
-        collate = method(functions.Collate)
-        json = staticmethod(functions.JSONObject)
-        random = staticmethod(functions.Random)
+    sha1 = method(functions.SHA1)
+    sha224 = method(functions.SHA224)
+    sha256 = method(functions.SHA256)
+    sha384 = method(functions.SHA384)
+    sha512 = method(functions.SHA512)
+    collate = method(functions.Collate)
+    json = staticmethod(functions.JSONObject)
+    random = staticmethod(functions.Random)
     if gis:  # pragma: no cover
         area = property(gis.functions.Area)
         geojson = method(gis.functions.AsGeoJSON)
@@ -327,7 +326,7 @@ class F(models.F, Lookup, metaclass=MetaF):
 
 
 def reduce(func):
-    return update_wrapper(lambda self: self.reduce(func), func.__name__)
+    return update_wrapper(lambda self, **extra: self.reduce(func, **extra), func.__name__)
 
 
 def field(func):
@@ -405,7 +404,7 @@ class QuerySet(models.QuerySet, Lookup):
         getter = operator.itemgetter(size if self._flat else slice(size, None))
         if self._named:
             Row = collections.namedtuple('Row', self._fields)
-            getter = lambda tup: Row(*tup[size:])  # noqa
+            getter = lambda tup: Row(*tup[size:])  # noqa: E731
         return ((key, map(getter, values)) for key, values in groups)
 
     def items(self, *fields, **annotations) -> 'QuerySet':
@@ -455,13 +454,13 @@ class QuerySet(models.QuerySet, Lookup):
         qs = self.order_by(*self._fields)
         return qs.reverse() if reverse else qs
 
-    def reduce(self, *funcs):
+    def reduce(self, *funcs, **extra):
         """Return aggregated values, or an annotated [QuerySet][model_values.QuerySet].
 
         Args:
             *funcs: aggregation function classes
         """
-        funcs = [func(field) for field, func in zip(self._fields, itertools.cycle(funcs))]
+        funcs = [func(field, **extra) for field, func in zip(self._fields, itertools.cycle(funcs))]
         if hasattr(self, '_groupby'):
             return self[self._groupby].annotate(*funcs)
         names = [func.default_alias for func in funcs]
@@ -593,7 +592,7 @@ class Manager(models.Manager):
         """
         if conditional:
             data = {pk: data[pk] for pk in self.bulk_changed(field, data, key)}
-        updates = collections.defaultdict(list)  # type: dict
+        updates = collections.defaultdict(list)
         for pk in data:
             updates[data[pk]].append(pk)
         if conditional:
@@ -640,9 +639,6 @@ class Case(models.Case):
 
     def __new__(cls, conds, default=None, **extra):
         cases = (models.When(cond, Value(conds[cond])) for cond in conds)
-        types = set(map(type, conds.values()))
-        if django.VERSION < (3, 2) and len(types) == 1 and types.issubset(cls.types):
-            extra.setdefault('output_field', cls.types.get(*types)())
         return models.Case(*cases, default=Value(default), **extra)
 
     @classmethod
